@@ -26,7 +26,8 @@
 #' @export
 ldply <- function(.data, .fun = NULL, ..., .progress = "none", .parallel = FALSE) {
   if (!inherits(.data, "split")) .data <- as.list(.data)
-  res <- llply(.data = .data, .fun = .fun, ..., .progress = .progress)
+  res <- llply(.data = .data, .fun = .fun, ..., 
+    .progress = .progress, .parallel = .parallel)
   
   list_to_dataframe(res, attr(.data, "split_labels"))
 }
